# Metromobilite
[![Build Status](https://travis-ci.org/PierreBerger/metromobilite.svg?branch=master)](https://travis-ci.org/PierreBerger/metromobilite)
[![Coverage Status](https://coveralls.io/repos/github/PierreBerger/metromobilite/badge.svg?branch=master)](https://coveralls.io/github/PierreBerger/metromobilite?branch=master)

Python library for [Metromobilite API](https://www.metromobilite.fr/pages/opendata/OpenDataApi.html)

Installation

```sh
pip install metromobilite
```

=====
```sh
git clone git@github.com:PierreBerger/metromobilite.git
cd metromobilite
python setup.py install
```

Usage
=====
### Import and initialization:
```python
from metromobilite import Metromobilite
m = Metromobilite()
```